@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -21,6 +21,7 @@
 
 package com.openexchange.nosql.cassandra.exceptions;
 
+import static com.openexchange.exception.OXExceptionStrings.MESSAGE;
 import com.openexchange.exception.Category;
 import com.openexchange.exception.DisplayableOXExceptionCode;
 import com.openexchange.exception.OXException;
@@ -80,12 +81,18 @@ public enum CassandraServiceExceptionCodes implements DisplayableOXExceptionCode
     /**
      * Initialises a new {@link CassandraServiceExceptionCodes}.
      */
-    private CassandraServiceExceptionCodes(final String message, final Category category, final int number) {
+    private CassandraServiceExceptionCodes(String message, Category category, int number) {
+        this(message, null, category, number);
+    }
+
+    /**
+     * Initialises a new {@link CassandraServiceExceptionCodes}.
+     */
+    private CassandraServiceExceptionCodes(String message, String displayMessage, Category category, int number) {
         this.message = message;
-        this.displayMessage = message;
+        this.displayMessage = null != displayMessage ? displayMessage : MESSAGE;
         this.category = category;
         this.number = number;
-
     }
 
     @Override
